<?php
/**
 * Switch functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package switch-lite
 */

if ( ! function_exists( 'switch_lite_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function switch_lite_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Switch, use a find and replace
		 * to change 'switch-lite' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'switch-lite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'switch-lite' ),
		) );


			/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'image',
		'video',
		'audio',
		'gallery',
		'link',
		'quote',
	) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'switch_lite_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'switch_lite_setup' );

/**
 * Filter the except length to 50 words.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */



function switch_lite_excerpt_length($length) {
    if ( is_admin() ) {
        return $length;
    }
    return 50;
}
add_filter('excerpt_length', 'switch_lite_excerpt_length');



/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function switch_lite_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'switch_lite_content_width', 640 );
}
add_action( 'after_setup_theme', 'switch_lite_content_width', 0 );

require_once(get_template_directory() . '/inc/custom-style.php');


/**
 * Enqueue scripts and styles.
 */
function switch_lite_scripts() {

							// Stytlesheet 


	// Opensans fonts 
	wp_enqueue_style('opensans', 'https://fonts.googleapis.com/css?family=Open+Sans:400,600' );

	// Kaushan fonts
	wp_enqueue_style('kaushan', 'https://fonts.googleapis.com/css?family=Kaushan+Script' );

	// Bootstap Stylesheet
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/dist/css/bootstrap.css');

	// Fontawesome Stylesheet
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/dist/css/font-awesome.css' );

	// Theme Stylesheet
	wp_enqueue_style( 'switch-lite-style', get_stylesheet_uri() );

	// Main Stylesheet
	wp_enqueue_style('switch-lite-core', get_template_directory_uri() . '/dist/css/switch.css', false, '', 'all'  );

	// customizer option code
	wp_add_inline_style( 'switch-lite-core', switch_lite_customizer_color() );
	wp_add_inline_style( 'switch-lite-core', switch_lite_header_image() );
	



	// Script Load

	// Bootstarp Script
	wp_enqueue_script( 'bootstarp-script', get_template_directory_uri() . '/dist/js/bootstrap.js', array('jquery'), '3.3.7', true );

	// Single page js
	wp_enqueue_script( 'nav', get_template_directory_uri() . '/dist/js/jquery.nav.js', array('jquery'), '3.0.0', true );

	// Main script js
	wp_enqueue_script( 'switch-lite-script', get_template_directory_uri() . '/dist/js/switch.js', array('jquery'), '', true );

	// touch keyboard js
	wp_enqueue_script( 'keyboad-script', get_template_directory_uri() . '/dist/js/touch-keyboard-navigation.js', array('jquery'), '', true );

	wp_enqueue_script( 'switch_lite-skip-link-focus-fix', get_template_directory_uri() . '/dist/js/skip-link-focus-fix.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'switch_lite_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Widgets
 */

require get_template_directory() . '/inc/widgets.php';

/**
 * Plugin activation
 */

	require get_template_directory() . '/inc/dependency.php';
	SwitchCore_Dependency::init();
/**
 * Plugin tgmpa
 */

//require get_template_directory() . '/plugin/class-tgm-plugin-activation.php';
