<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package switch-lite
 */

	// Preloader Enable/Disable
    $switch_preloader = get_theme_mod( 'preloader_enable', 'true');

    // Preloader title
    $preloader_title  = get_theme_mod( 'preloader_title');

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>


<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'switch-lite' ); ?></a>

        <?php if ( $switch_preloader): ?>
            <!-- Preloader -->
            <div id="preloader">
              <div id="top" class="mask">
                <div class="plane"></div>
              </div>
              <div id="middle" class="mask">
                <div class="plane"></div>
              </div>

              <div id="bottom" class="mask">
                <div class="plane"></div>
              </div>
              <?php if($preloader_title): ?>
                <p class="loading-title">
                    <i><?php echo esc_html($preloader_title);?></i>
                </p>
              <?php endif; ?>
         </div>   <!-- ./preloader -->
      <?php endif ?>

	    <?php if (is_front_page() && ! is_home()):?>
		  	<header id="header" class="onepage-header">
		      <nav class="navbar navbar-default onepage-nav" data-spy="affix" data-offset-top="100">
		<?php elseif(is_home()): ?>
			<header id="header" class="site-header">
		      <nav class="navbar navbar-default">
	    <?php else: ?>
			<header id="header" class="site-header">
		      <nav class="navbar navbar-default">
		<?php endif;?>
          <div class="container">
	          <div class="row">
	          	
	         
	         	 <div class="col-md-4">
	              	<div class="navbar-header">
	                  	<button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#switch-mobile-menu">
	                      <span class="sr-only"><?php esc_html_e('Toggle navigation', 'switch-lite');?></span>
	                      <span class="icon-bar"></span>
	                      <span class="icon-bar"></span>
	                      <span class="icon-bar"></span>
	                    </button>

						<?php $description = get_bloginfo( 'description', 'display' ); ?>
						
						<?php if(has_custom_logo()):?>
							<?php the_custom_logo();?>

						<?php if ( is_front_page() && is_home() ) : ?>

							<h1 class="site-title">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
									<?php bloginfo( 'name' ); ?>
								</a>
							</h1>
						<?php else : ?>
							<h1 class="site-title">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>" >
									<?php bloginfo( 'name' ); ?>
								</a>
							</h1>
						<?php endif;

							
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description">
								<?php echo esc_html($description); ?>	
							</p>
						<?php endif; ?>

						<?php elseif($description || is_customize_preview() ): ?>

							<?php if ( is_front_page() && is_home() ) : ?>

								<h1 class="site-title">
									<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
										<?php bloginfo( 'name' ); ?>
									</a>
								</h1>
							<?php else : ?>
								<h1 class="site-title">
									<a href="<?php echo esc_url( home_url( '/' ) ); ?>" >
										<?php bloginfo( 'name' ); ?>	
									</a>
								</h1>
							<?php endif;

							
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description">
									<?php echo esc_html($description);?>
								</p>
							<?php endif; ?>

						<?php else: ?>
							<h1 class="site-title">
								<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
									<?php bloginfo( 'name' ); ?>
								</a>
							</h1>
							<p class="site-description">
								<?php echo esc_html($description);?>
							</p>
						<?php endif;?>

	              	</div>  <!-- end of /.navbar-header -->
	            </div>  <!-- end of /.col-md-4 -->

	            <div class="col-md-8">
		            <div class="collapse navbar-collapse navbar-right" id="switch-mobile-menu">
				            <?php 
				            	if( is_front_page() && is_home()){
									// Default menu
									wp_nav_menu( 
						                array( 
							                'theme_location' => 'primary', 
							                'menu' => 'primary',
							                'fallback_cb'    => 'wp_bootstrap_navwalker::fallback',
							                'menu_class' => 'nav navbar-nav'
						                ) 
					                ); 

									} elseif ( is_front_page()){
									//Affix menu
									wp_nav_menu( 
						                array( 
							                'theme_location' => 'onepage', 
							                'menu' => 'onepage', 
							                'fallback_cb' => 'wp_bootstrap_navwalker::fallback',
							                'menu_class' => 'nav navbar-nav onepage'
						                ) 
					                ); 
								} elseif ( is_home()){

								//Blog page
								wp_nav_menu( 
					                array( 
						                'theme_location' => 'primary', 
						                'menu' => 'primary', 
						                'fallback_cb'  => 'wp_bootstrap_navwalker::fallback',
						                'menu_class' => 'nav navbar-nav'
						            ) 
				                ); 

							} else {

								//everything else
								wp_nav_menu( 
					                array( 
						                'theme_location' => 'primary', 
						                'menu' => 'primary', 
						                'fallback_cb'       => 'wp_bootstrap_navwalker::fallback',
						                'menu_class' => 'nav navbar-nav'
						            ) 
					            ); 

							}
		 				?>
		            </div>
	            </div>  <!-- end of /.col-md-8 -->
           	</div><!-- end of /.row -->
          </div> <!-- end of /.container -->
     	</nav> <!-- end of /.nav -->
    </header> <!-- end of /.header -->



	<div id="content" class="site-content">
