<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package switch-lite
 */

if ( ! function_exists( 'switch_lite_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function switch_lite_posted_on() {

		$posted_on = sprintf(
			/* translators: %s: post date. */
			__( 'Posted On :  %s', 'switch-lite' ),
			'<a href="' . esc_url( get_permalink() ) . '">' . get_the_date() . '</a>'
		);

		$byline = sprintf(
			/* translators: %s: post author. */
			__( 'By : %s', 'switch-lite' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);
		?>
			<span class="posted-on">
				<?php echo wp_kses_post($posted_on);?>
			</span>
			<span class="byline">
				<?php echo wp_kses_post($byline);?>
			</span>
		
		<?php

	}
endif;


if ( ! function_exists( 'switch_lite_time_link' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function switch_lite_time_link() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		get_the_date( DATE_W3C ),
		get_the_date(),
		get_the_modified_date( DATE_W3C ),
		get_the_modified_date()
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'switch-lite' ),
		'<a href="' . esc_url( get_permalink() ) . '">' . $time_string . '</a>'
	);
}
endif;


function switch_lite_edit_link() {
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			__( 'Edit<span class="screen-reader-text"> "%s"</span>', 'switch-lite' ),
			get_the_title()
		),
		'<span class="edit-link">',
		'</span>'
	);
}

if ( ! function_exists( 'switch_lite_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function switch_lite_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( __( ', ', 'switch-lite' ) ); 
			 if ( $categories_list ) {
			 	echo wp_kses_post('<span class="cat-links">' . esc_html__('Categorys : ', 'switch-lite' ) . $categories_list . '</span>');
				
			 }

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', ' , ' );
			if ( $tags_list ) {
				echo wp_kses_post('<span class="cat-links">' . esc_html__('Tags : ', 'switch-lite' ) . $tags_list . '</span>');
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					printf(
						/* translators: %s: post title */
						esc_html__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'switch-lite' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
		sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'switch-lite' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;
